@@ -366,6 +366,7 @@ namespace Tomboy
 				"\tJoe Shaw",
 				"\tJohn Anderson",
 				"\tJohn Carr",
+                "\tJohn Harrison",
 				"\tJon Lund Steffensen",
 				"\tJP Rosevear",
 				"\tKevin Kubasik",
@@ -393,6 +394,7 @@ namespace Tomboy
 				"\tRobin Sonefors",
 				"\tRodrigo Moya",
 				"\tRomain Tartiere",
+                "\tRoman Yepishev",
 				"\tRyan Lortie",
 				"\tSam Lin",
 				"\tSebastian Dröge",
